@@ -1,5 +1,7 @@
 """CLI tests for tmuxp's core shell functionality."""
 
+from __future__ import annotations
+
 import argparse
 import contextlib
 import pathlib
@@ -37,7 +39,7 @@ def test_creates_config_dir_not_exists(tmp_path: pathlib.Path) -> None:
     ],
 )
 def test_help(
-    cli_args: t.List[str],
+    cli_args: list[str],
     tmp_path: pathlib.Path,
     monkeypatch: pytest.MonkeyPatch,
     capsys: pytest.CaptureFixture[str],
@@ -63,7 +65,7 @@ def test_resolve_behavior(
     expect = tmp_path
     monkeypatch.chdir(tmp_path)
     assert pathlib.Path("../").resolve() == expect.parent
-    assert pathlib.Path().resolve() == expect
+    assert pathlib.Path.cwd() == expect
     assert pathlib.Path("./").resolve() == expect
     assert pathlib.Path(expect).resolve() == expect
 
@@ -112,7 +114,7 @@ def test_pass_config_dir_argparse(
     def config_cmd(workspace_file: str) -> None:
         tmuxp_echo(find_workspace_file(workspace_file, workspace_dir=configdir))
 
-    def check_cmd(config_arg: str) -> "_pytest.capture.CaptureResult[str]":
+    def check_cmd(config_arg: str) -> _pytest.capture.CaptureResult[str]:
         args = parser.parse_args([config_arg])
         config_cmd(workspace_file=args.workspace_file)
         return capsys.readouterr()
@@ -130,7 +132,7 @@ def test_pass_config_dir_argparse(
 
 def test_reattach_plugins(
     monkeypatch_plugin_test_packages: None,
-    server: "Server",
+    server: Server,
 ) -> None:
     """Test reattach plugin hook."""
     config_plugins = test_utils.read_workspace_file("workspace/builder/plugin_r.yaml")
