@@ -1,5 +1,7 @@
 """Test for tmuxp tmuxinator configuration."""
 
+from __future__ import annotations
+
 import typing as t
 
 import pytest
@@ -31,8 +33,8 @@ from tmuxp.workspace import importers, validation
 )
 def test_config_to_dict(
     tmuxinator_yaml: str,
-    tmuxinator_dict: t.Dict[str, t.Any],
-    tmuxp_dict: t.Dict[str, t.Any],
+    tmuxinator_dict: dict[str, t.Any],
+    tmuxp_dict: dict[str, t.Any],
 ) -> None:
     """Test exporting tmuxinator configuration to dictionary."""
     yaml_to_dict = ConfigReader._load(fmt="yaml", content=tmuxinator_yaml)
